package com.inspect.patrol.mapper;

import com.inspect.patrol.domain.PatrolLinkageStrategyReverse;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface PatrolLinkageStrategyReverseMapper {
    PatrolLinkageStrategyReverse selectPatrolLinkageStrategyReverseByLinkageStrategyRefId(Long refId);

    List<PatrolLinkageStrategyReverse> selectPatrolLinkageStrategyReverseList(PatrolLinkageStrategyReverse reverse);

    int insertPatrolLinkageStrategyReverse(PatrolLinkageStrategyReverse reverse);

    int insertPatrolLinkageStrategyReverses(List<PatrolLinkageStrategyReverse> reverseList);

    int updatePatrolLinkageStrategyReverse(PatrolLinkageStrategyReverse reverse);

    int deletePatrolLinkageStrategyReverseByLinkageStrategyReverseId(Long reverseId);

    int deletePatrolLinkageStrategyReverseByLinkageStrategyReverseIds(Long[] reverseIds);
}
